pub struct ProgramResponse {
pub object_id: String,
pub storage_address: String,
}Expand description
ProgramResponse
ProgramResponse carry elements to locate the program in a axone-objectarium contract.
Fields
object_id: StringThe program object id in the axone-objectarium contract.
storage_address: StringThe axone-objectarium contract address on which the law program is stored.